Process _swft_ files generated by the _swift_ tracking software.

## Provided Functions
`load(path: str)`  
Load a _swft_ file specified by `path`.  
Returns a dictonary of type `{table_name: table}`. Each table is represented by a _pandas_ `DataFrame` with four additional attributes:

- `child: str`: Name of the child table (if any)
- `id_col: str`: Name of column in child table that contains the row ID of the parent
- `pos_col: str`: Name of column in child table that contains the position in parent (optional)
- `units: list`: Column units

`dump(dataset: dict, path: str)`  
Save `dataset`, a dictionary as specified above, to a file specified by `path`.
